[![PyPI version](https://badge.fury.io/py/plumbing.svg)](https://badge.fury.io/py/plumbing)
[![changelog](http://allmychanges.com/p/python/plumbing/badge/)](http://allmychanges.com/p/python/plumbing/?utm_source=badge)

# `plumbing` version 2.2.5

This project contains functions and classes that help with plumbing-type programing.

More documentation is available at:
http://xapple.github.io/plumbing/